<?php
    require_once( 'library/besteurful.php' );
    
    function besteurful_ahoy() {
        
        add_editor_style( get_stylesheet_directory_uri() . '/library/css/editor-style.css' );
        load_theme_textdomain( 'besteurfultheme', get_template_directory() . '/library/translation' );
        
        require_once( 'library/custom-post-type.php' );
        
        add_action( 'init', 'besteurful_head_cleanup' );
        add_filter( 'wp_title', 'rw_title', 10, 3 );
        add_filter( 'the_generator', 'besteurful_rss_version' );
        add_filter( 'wp_head', 'besteurful_remove_wp_widget_recent_comments_style', 1 );
        add_action( 'wp_head', 'besteurful_remove_recent_comments_style', 1 );
        add_filter( 'gallery_style', 'besteurful_gallery_style' );
        add_action( 'wp_enqueue_scripts', 'besteurful_scripts_and_styles', 999 );
        
        besteurful_theme_support();
        
        add_action( 'widgets_init', 'besteurful_register_sidebars' );
        add_filter( 'the_content', 'besteurful_filter_ptags_on_images' );
        add_filter( 'excerpt_more', 'besteurful_excerpt_more' );
    }
    add_action( 'after_setup_theme', 'besteurful_ahoy' );
    
    if ( ! isset( $content_width ) ) {
        $content_width = 800;
    }
    
    add_image_size( 'besteurful-thumb-600', 600, 150, true );
    add_image_size( 'besteurful-thumb-300', 300, 100, true );
    
    add_filter( 'image_size_names_choose', 'besteurful_custom_image_sizes' );
    
    function besteurful_custom_image_sizes ( $sizes ) {
        return array_merge( $sizes, array(
                                          'besteurful-thumb-600' => __('600px by 150px'),
                                          'besteurful-thumb-300' => __('300px by 100px'),
                                          ) );
    }
    
    function besteurful_register_sidebars () {
		register_sidebar(
			array(
				'id'			=> 'sidebar1',
				'name'			=> __( 'Sidebar', 'besteurfultheme' ),
				'description'	=> __( 'The first (primary) sidebar.', 'besteurfultheme' ),
				'before_widget'	=> '<div id="%1$s" class="widget %2$s">',
				'after_widget'	=> '</div>',
				'before_title'	=> '<div class="shadow-top"></div><h4 class="widgettitle">',
				'after_title'	=> '</h4><div class="shadow-bottom"></div>',
			)
		);
		register_sidebar (
			array (
				'name'			=> __( 'Footer', 'besteurfultheme' ),
				'id'			=> 'sidebar2',
				'description'	=> __( 'Deze widgets verschijnen aan de onderkant van de pagina.', 'besteurfultheme' ),
				'before_widget'	=> '<div id="%1$s" class="widget-footer %2$s">',
				'after_widget'	=> '</div>',
				'before_title'	=> '<div style="background: white none repeat scroll 0% 0%; border-radius: 15px;"><div class="shadow-bottom"></div><h4 class="widgettitle">',
				'after_title'	=> '</h4><div class="shadow-top"></div></div>',
			)
		);
	}

function besteurful_comments( $comment, $args, $depth ) {
	
	$GLOBALS['comment'] = $comment; ?>

<div id="comment-<?php comment_ID(); ?>" <?php comment_class('cf'); ?>>
	<article  class="cf">
		<header class="comment-author vcard">
			<?php $bgauthemail = get_comment_author_email(); ?>
			<img data-gravatar="http://www.gravatar.com/avatar/<?php echo md5( $bgauthemail ); ?>?s=40" class="load-gravatar avatar avatar-48 photo" height="40" width="40" src="<?php echo get_template_directory_uri(); ?>/library/images/nothing.gif" />
			<?php printf(__( '<cite class="fn">%1$s</cite> %2$s', 'besteurfultheme' ), get_comment_author_link(), edit_comment_link(__( '(Edit)', 'besteurfultheme' ),'  ','') ) ?>
			<time datetime="<?php echo comment_time('Y-m-j'); ?>">
				<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>">
					<?php comment_time(__( 'F jS, Y', 'besteurfultheme' )); ?>
				</a>
			</time>
		</header>
		
		<?php if ($comment->comment_approved == '0') : ?>
		<div class="alert alert-info">
			<p><?php _e( 'Your comment is awaiting moderation.', 'besteurfultheme' ) ?></p>
		</div>
		<?php endif; ?>
		
		<section class="comment_content cf">
			<?php comment_text() ?>
		</section>
		
		<?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
	</article>
	<?php
}

function besteurful_fonts() {
	wp_enqueue_style('googleFonts', 'http://fonts.googleapis.com/css?family=Lato:400,700,400italic,700italic');
}
add_action('wp_enqueue_scripts', 'besteurful_fonts');

function bsMenu() {
	add_theme_page (
		'BeSteurful Theme Options',
		'Theme Options',
		'manage_options',
		'besteurfultheme',
		'bsSettingsPage'
	);
	add_action( 'admin_init', 'bsSettings' );
}
add_action('admin_menu', 'bsMenu');

function bsSettings () {
	register_setting ( 'besteurfultheme', 'header-image');
	
	register_setting ( 'besteurfultheme', 'featured');
	
	register_setting ( 'besteurfultheme', 'media-facebook' );
	register_setting ( 'besteurfultheme', 'media-linkedin' );
	register_setting ( 'besteurfultheme', 'media-youtube' );
	register_setting ( 'besteurfultheme', 'media-rss' );
	register_setting ( 'besteurfultheme', 'media-email' );
}

function bsSettingsPage() {
?>
	<div class="wrap">
		<h2>
			BeSteurful Theme Options
		</h2>
		
		<form method="post" action="options.php">
			<?php settings_fields( 'besteurfultheme' ); ?>
			<?php do_settings_sections( 'besteurfultheme' ); ?>
			
			<h3>Front Page</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row">Featured Image URL</th>
					<td>
						<input style="width: 100%;" type="text" name="header-image" value="<?php echo esc_attr( get_option('header-image') ); ?>" />
					</td>
				</tr>
				
				<tr valign="top">
					<th scope="row">Featured Page/Post ID</th>
					<td>
						<input style="width: 100%;" type="text" name="featured" value="<?php echo esc_attr( get_option('featured') ); ?>" />
					</td>
				</tr>
			</table>
				
			<br>
			
			<h3>Social Media Icons</h3>
			<table class="form-table">
				<tr valign="top">
					<th scope="row">Facebook Url</th>
						<td>
							<input
						style="width: 100%;"
						type="text"
						name="media-facebook"
							value="<?php echo esc_attr( get_option('media-facebook') ); ?>"
						/>
					</td>
				</tr>
				
				<tr valign="top">
					<th scope="row">LinkedIn Url</th>
					<td>
						
						<input
						style="width: 100%;"
						type="text"
						name="media-linkedin"
						value="<?php echo esc_attr( get_option('media-linkedin') ); ?>"
					/>
				</td>
			</tr>
			
			<tr valign="top">
				<th scope="row">YouTube Url</th>
				<td>
					<input
					style="width: 100%;"
					type="text"
					name="media-youtube"
					value="<?php echo esc_attr( get_option('media-youtube') ); ?>"
					/>
				</td>
			</tr>
			
			<tr valign="top">
				<th scope="row">RSS Feed Url</th>
				<td><input style="width: 100%;" type="text" name="media-rss" value="<?php echo esc_attr( get_option('media-rss') ); ?>" /></td>
			</tr>
			
			<tr valign="top">
				<th scope="row">E-Mail</th>
				<td>
					<input
					style="width: 100%;"
					type="text"
					name="media-email"
					value="<?php echo esc_attr( get_option('media-email') ); ?>"
					/>
				</td>
			</tr>
		</table>
		
		<?php submit_button(); ?>
	</form>
</div>
<?php }

function show_post ( $id ) {
	$post = get_post($id);
	$content = apply_filters('the_content', $post->post_content); 
	echo $content;  
}

function menu_search($items){
    $search = '<li class="search" style="float: right;">';
    $search .= '<form method="get" id="searchform" action="/">';
    $search .= '<input type="text" class="field" name="s" id="s" placeholder="Zoeken" style="float: left; display: inline-block; width: 150px;"/>';
    $search .= '<input type="submit" class="submit" name="submit" id="searchsubmit" value="Zoeken" style="float: right; display: inline-block; height: 40px;"/>';
    $search .= '</form>';
    $search .= '</li>';

    return $items . $search;
}
add_filter('wp_nav_menu_items','menu_search');

function menu_social ( $items, $args ) {
	
	if ( esc_attr( get_option ( 'media-email' ) ) != null ) {
		$items .= '<li class="menu-item social mi-mail" style="float: right;"><a href="mailto:';
		$items .= esc_attr( get_option ( 'media-email' ) );
		$items .= '"></a></li>';
	}
	
	if ( esc_attr( get_option ( 'media-rss' ) ) != null ) {
		$items .= '<li class="menu-item social mi-rss" style="float: right;"><a href="';
		$items .= esc_attr( get_option ( 'media-rss' ) );
		$items .= '" target="_blank"></a></li>';
	}
	
	if ( esc_attr( get_option ( 'media-youtube' ) ) != null ) {
		$items .= '<li class="menu-item social mi-youtube" style="float: right;"><a href="';
		$items .= esc_attr( get_option ( 'media-youtube' ) );
		$items .= '" target="_blank"></a></li>';
	}
	
	if ( esc_attr( get_option ( 'media-linkedin' ) ) != null ) {
		$items .= '<li class="menu-item social mi-linkedin" style="float: right;"><a href="';
		$items .= esc_attr( get_option ( 'media-linkedin' ) );
		$items .= '" target="_blank"></a></li>';
	}
	
	if ( esc_attr( get_option ( 'media-facebook' ) ) != null ) {
		$items .= '<li class="menu-item social mi-facebook" style="float: right;"><a href="';
		$items .= esc_attr( get_option ( 'media-facebook' ) );
		$items .= '" target="_blank"></a></li>';
	}
	
	return $items;
}
add_filter( 'wp_nav_menu_items', 'menu_social', 10, 2 );
?>
	