<?php
function besteurful_head_cleanup() {
	remove_action( 'wp_head', 'feed_links_extra', 3 );
	remove_action( 'wp_head', 'feed_links', 2 );
	remove_action( 'wp_head', 'rsd_link' );
	remove_action( 'wp_head', 'wlwmanifest_link' );
	remove_action( 'wp_head', 'parent_post_rel_link', 10, 0 );
	remove_action( 'wp_head', 'start_post_rel_link', 10, 0 );
	remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );
	remove_action( 'wp_head', 'wp_generator' );
	add_filter( 'style_loader_src', 'besteurful_remove_wp_ver_css_js', 9999 );
	add_filter( 'script_loader_src', 'besteurful_remove_wp_ver_css_js', 9999 );
}

function rw_title( $title, $sep, $seplocation ) {
	global $page, $paged;
	
	if ( is_feed() ) return $title;
	
	if ( 'right' == $seplocation ) {
		$title .= get_bloginfo( 'name' );
	} else {
		$title = get_bloginfo( 'name' ) . $title;
	}
	
	$site_description = get_bloginfo( 'description', 'display' );
	
	if ( $site_description && ( is_home() || is_front_page() ) ) {
		$title .= " {$sep} {$site_description}";
	}
	
	if ( $paged >= 2 || $page >= 2 ) {
		$title .= " {$sep} " . sprintf( __( 'Page %s', 'dbt' ), max( $paged, $page ) );
	}
	
	return $title;
}

function besteurful_rss_version() { return ''; }

function besteurful_remove_wp_ver_css_js( $src ) {
	if ( strpos( $src, 'ver=' ) )
		$src = remove_query_arg( 'ver', $src );
	return $src;
}

function besteurful_remove_wp_widget_recent_comments_style() {
	if ( has_filter( 'wp_head', 'wp_widget_recent_comments_style' ) ) {
		remove_filter( 'wp_head', 'wp_widget_recent_comments_style' );
	}
}

function besteurful_remove_recent_comments_style() {
	
	global $wp_widget_factory;
	
	if (isset($wp_widget_factory->widgets['WP_Widget_Recent_Comments'])) {
		remove_action(
			'wp_head',
			array(
				$wp_widget_factory->widgets['WP_Widget_Recent_Comments'],
				'recent_comments_style'
			)
		);
	}
}

function besteurful_gallery_style($css) {
	return preg_replace( "!<style type='text/css'>(.*?)</style>!s", '', $css );
}

function besteurful_scripts_and_styles() {
	
	global $wp_styles;
	
	if (!is_admin()) {
		
		wp_register_script( 'besteurful-modernizr', get_stylesheet_directory_uri() . '/library/js/libs/modernizr.custom.min.js', array(), '2.5.3', false );
		wp_register_style( 'besteurful-stylesheet', get_stylesheet_directory_uri() . '/library/css/style.css', array(), '', 'all' );
		wp_register_style( 'besteurful-ie-only', get_stylesheet_directory_uri() . '/library/css/ie.css', array(), '' );
		
		if ( is_singular() AND comments_open() AND (get_option('thread_comments') == 1)) {
			wp_enqueue_script( 'comment-reply' );
		}
		
		wp_register_script( 'besteurful-js', get_stylesheet_directory_uri() . '/library/js/scripts.js', array( 'jquery' ), '', true );
		wp_enqueue_script( 'besteurful-modernizr' );
		wp_enqueue_style( 'besteurful-stylesheet' );
		wp_enqueue_style( 'besteurful-ie-only' );
		
		$wp_styles->add_data( 'besteurful-ie-only', 'conditional', 'lt IE 9' );
		
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'besteurful-js' );
	}
}

function besteurful_theme_support() {
	
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size(125, 125, true);
	add_theme_support('automatic-feed-links');
	add_theme_support( 'menus' );
	register_nav_menus(
		array(
			'main-nav' => __( 'The Main Menu', 'besteurfultheme' ),
			'footer-links' => __( 'Footer Links', 'besteurfultheme' )
		)
	);
	add_theme_support(
		'html5',
		array(
			'comment-list',
			'search-form',
			'comment-form'
		)
	);
}

function besteurful_related_posts() {
	
	echo '<ul id="besteurful-related-posts">';
	global $post;
	$tags = wp_get_post_tags( $post->ID );
	
	if($tags) {
		foreach( $tags as $tag ) {
			$tag_arr .= $tag->slug . ',';
		}
		
		$args = array(
			'tag' => $tag_arr,
			'numberposts' => 5,
			'post__not_in' => array($post->ID)
		);
		$related_posts = get_posts( $args );
		
		if($related_posts) {
			foreach ( $related_posts as $post ) : setup_postdata( $post ); ?>

<li class="related_post">
	<a class="entry-unrelated" href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>">
		<?php the_title(); ?>
	</a>
</li>
<?php
			endforeach;
		}
		
		else {
			echo '<li class="no_related_post">' . __( 'No Related Posts Yet!', 'besteurfultheme' ) . '</li>';
		}
	}
	wp_reset_postdata();
	
	echo '</ul>';
}

function besteurful_page_navi() {
	
	global $wp_query;
	$bignum = 999999999;
	
	if ( $wp_query->max_num_pages <= 1 )
		return;
	
	echo '<nav class="pagination">';
	echo paginate_links(
		array(
			'base'         => str_replace( $bignum, '%#%', esc_url( get_pagenum_link($bignum) ) ),
			'format'       => '',
			'current'      => max( 1, get_query_var('paged') ),
			'total'        => $wp_query->max_num_pages,
			'prev_text'    => '&larr;',
			'next_text'    => '&rarr;',
			'type'         => 'list',
			'end_size'     => 3,
			'mid_size'     => 3
		)
	);
	echo '</nav>';
}

function besteurful_filter_ptags_on_images($content){
	return preg_replace('/<p>\s*(<a .*>)?\s*(<img .* \/>)\s*(<\/a>)?\s*<\/p>/iU', '\1\2\3', $content);
}

function besteurful_excerpt_more($more) {
	global $post;
	return '...  <a class="excerpt-read-more" href="'. get_permalink( $post->ID ) . '" title="'. __( 'Read ', 'besteurfultheme' ) . esc_attr( get_the_title( $post->ID ) ).'">'. __( 'Read more &raquo;', 'besteurfultheme' ) .'</a>';
} ?>